@@ -11,12 +11,6 @@ from magic_admin.django.exceptions import (
 )
 from magic_admin.error import (
     DIDTokenError,
-    APIConnectionError,
-    RateLimitingError,
-    BadRequestError,
-    AuthenticationError,
-    ForbiddenError,
-    APIError,
 )
 
 from magic_admin.utils.http import get_identity_token_from_header
@@ -30,6 +24,17 @@ from magic_admin.utils.logging import (
 user_model = get_user_model()
 
 
+def _lower_case(value):
+    if isinstance(value, str):
+        return value.lower()
+    else:
+        return False
+
+
+def _match_email(user, email):
+    return _lower_case(user.email) == _lower_case(email)
+
+
 class MagicAuthBackend(ModelBackend):
 
     @staticmethod
@@ -50,18 +55,11 @@ class MagicAuthBackend(ModelBackend):
             Magic().Token.validate(identity_token)
         except (
                 DIDTokenError,
-                APIConnectionError,
-                RateLimitingError,
-                BadRequestError,
-                AuthenticationError,
-                ForbiddenError,
-                APIError,
         ) as e:
             log_debug(
                 'DID Token failed validation. No user is to be retrieved.',
                 error_class=e.__class__.__name__,
             )
-            raise e
             return None
 
         try:
@@ -69,7 +67,7 @@ class MagicAuthBackend(ModelBackend):
         except user_model.DoesNotExist:
             raise PublicAddressDoesNotExist()
 
-        if user.email != email:
+        if not _match_email(user, email):
             raise UserEmailMissmatch()
 
         return user
